<div class="alert alert-warning" role="alert">
    <strong>Warning:</strong> This is work in progress. The model does
    not include post-exposure prophylaxis or community transmission.
    We would love to hear your feedback on the model. All the source
    code is available <a href="https://github.com/UofUEpiBio/epiworldRShiny/tree/measlesquarantine">here</a>.
</div>

# Modeling Measles in Schools

This model simulates measles outbreaks in schools and compares **how many fewer cases a quarantine procedure yields**. You can specify the number of people in the school (population size), the number of students initially infected with measles (initial cases), the proportion of students who are vaccinated before the outbreak, and the simulation duration in days. 

Note that the model only simulates outbreaks among students within a single school. It does not include transmissions from the students to people in other locations (e.g., other schools, households, the community, etc.) and does not include measles introductions to the school after the initial cases. Learn more about the model at <https://github.com/EpiForeSITE/epiworld-measles>.

